@@ -1,20 +1,26 @@
 from django.utils import unittest
 from django.utils.translation import activate
 from django import template
+from django.conf.urls.defaults import patterns, url
+from django.core import urlresolvers
 
-from models import Tree, TreeItem
-from sitetreeapp import SiteTree, SiteTreeError, register_items_hook, register_i18n_trees
+from sitetree.models import Tree, TreeItem
+from sitetree.sitetreeapp import SiteTree, SiteTreeError, register_items_hook, register_i18n_trees
+
+
+urlpatterns = patterns('',
+    url(r'articles/', lambda r: None, name='articles_list'),
+    url(r'articles/(\d+)/', lambda r: None, name='articles_detailed'),
+)
 
 
 class MockRequest(object):
-
     def __init__(self, path, user_authorized):
         self.path = path
         self.user = MockUser(user_authorized)
 
 
 class MockUser(object):
-
     def __init__(self, authorized):
         self.authorized = authorized
 
@@ -23,11 +29,11 @@ class MockUser(object):
 
 
 def get_mock_context(app=None, path=None, user_authorized=False, tree_item=None):
-    return template.Context({'request': MockRequest(path, user_authorized), 't2_root2_title': 'my_real_title', 'art_id': 10, 'tree_item': tree_item}, current_app=app)
+    return template.Context({'request': MockRequest(path, user_authorized), 't2_root2_title': 'my_real_title',
+                             'art_id': 10, 'tree_item': tree_item}, current_app=app)
 
 
 class TreeModelTest(unittest.TestCase):
-
     def test_create_rename_delete(self):
         tree = Tree(alias='mytree')
         tree.save(force_insert=True)
@@ -47,7 +53,6 @@ class TreeModelTest(unittest.TestCase):
 
 
 class TreeItemModelTest(unittest.TestCase):
-
     @classmethod
     def setUpClass(cls):
         cls.sitetree = SiteTree()
@@ -64,7 +69,8 @@ class TreeItemModelTest(unittest.TestCase):
         t1_root_child2 = TreeItem(title='child2', tree=t1, parent=t1_root, url='articles_list', urlaspattern=True)
         t1_root_child2.save(force_insert=True)
 
-        t1_root_child2_sub1 = TreeItem(title='subchild1', tree=t1, parent=t1_root_child2, url='articles_detailed art_id', urlaspattern=True)
+        t1_root_child2_sub1 = TreeItem(title='subchild1', tree=t1, parent=t1_root_child2,
+            url='articles_detailed art_id', urlaspattern=True)
         t1_root_child2_sub1.save(force_insert=True)
 
         t1_root_child2_sub2 = TreeItem(title='subchild2', tree=t1, parent=t1_root_child2, url='/not_articles/10/')
@@ -95,6 +101,14 @@ class TreeItemModelTest(unittest.TestCase):
         cls.t2_root2 = t2_root2
         cls.t2_root3 = t2_root3
 
+        # set urlconf to test's one
+        cls.old_urlconf = urlresolvers.get_urlconf()
+        urlresolvers.set_urlconf('sitetree.tests')
+
+    @classmethod
+    def tearDownClass(cls):
+        urlresolvers.set_urlconf(cls.old_urlconf)
+
     def test_no_tree(self):
         ti = TreeItem(title='notree_item')
         self.assertRaises(Exception, ti.save)
@@ -196,7 +210,6 @@ class TreeItemModelTest(unittest.TestCase):
         self.assertEqual(st2[1].has_children, False)
 
     def test_items_hook_tree(self):
-
         def my_processor(tree_items, tree_sender):
             for item in tree_items:
                 item.title_resolved = 'FakedTreeItem'
@@ -209,7 +222,6 @@ class TreeItemModelTest(unittest.TestCase):
         self.assertEqual(items[0].title_resolved, 'FakedTreeItem')
 
     def test_items_hook_menu(self):
-
         def my_processor(tree_items, tree_sender):
             for item in tree_items:
                 item.title_resolved = 'FakedMenuItem'
@@ -222,7 +234,6 @@ class TreeItemModelTest(unittest.TestCase):
         self.assertEqual(items[0].title_resolved, 'FakedMenuItem')
 
     def test_items_hook_breadcrumbs(self):
-
         def my_processor(tree_items, tree_sender):
             for item in tree_items:
                 item.title_resolved = 'FakedBreadcrumbsItem'
@@ -236,7 +247,6 @@ class TreeItemModelTest(unittest.TestCase):
 
 
 class TreeTest(unittest.TestCase):
-
     @classmethod
     def setUpClass(cls):
         cls.sitetree = SiteTree()
@@ -296,7 +306,6 @@ class TreeTest(unittest.TestCase):
         self.assertEqual(len(tree), 0)
 
     def test_register_i18n_trees(self):
-
         register_i18n_trees(['tree3'])
         self.sitetree.global_context = get_mock_context(path='/')
 
